package nc.impl.gl.accbookprint;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Set;
import java.util.Map.Entry;
import nc.bs.logging.Logger;

public class LRUCache2 {

   private static final float hashTableLoadFactor = 0.75F;
   private LinkedHashMap map;
   private int cacheSize;
   private Entry eldestKey;


   public LRUCache2(int cacheSize) {
      this.cacheSize = cacheSize;
      final int hashTableCapacity = (int)Math.ceil((double)((float)cacheSize / 0.75F)) + 1;
      this.map = new LinkedHashMap(hashTableCapacity, 0.75F, true) {

         private static final long serialVersionUID = 1L;

         protected boolean removeEldestEntry(Entry eldest) {
            LRUCache2.this.eldestKey = eldest;
            return this.size() > LRUCache2.this.cacheSize;
         }
      };
   }

   public synchronized Object get(Object key) {
      return this.map.get(key);
   }

   public synchronized void put(Object key, Object value) {
      Logger.debug("#############put" + key.toString());
      Logger.debug("#############Key" + this.map.keySet().size());
      this.map.put(key, value);
   }

   public synchronized void clear() {
      this.map.clear();
   }

   public synchronized void remove(Object key) {
      Logger.debug("#############remove" + key.toString());
      Logger.debug("#############remove" + this.map.keySet().size());
      this.map.remove(key);
   }

   public synchronized Set keySet() {
      return this.map.keySet();
   }

   public synchronized int usedEntries() {
      return this.map.size();
   }

   public static void main(String[] args) {
      LRUCache2 c = new LRUCache2(3);
      c.put("1", "one");
      c.put("2", "two");
      c.put("3", "three");
      c.put("4", "four");
      if(c.get("2") == null) {
         throw new Error();
      } else {
         c.put("5", "five");
         c.put("4", "second four");
         if(c.usedEntries() != 3) {
            throw new Error();
         } else if(!((String)c.get("4")).equals("second four")) {
            throw new Error();
         } else if(!((String)c.get("5")).equals("five")) {
            throw new Error();
         } else if(!((String)c.get("2")).equals("two")) {
            throw new Error();
         } else {
            Iterator var2 = c.getAll().iterator();

            while(var2.hasNext()) {
               Entry e = (Entry)var2.next();
               System.out.println((String)e.getKey() + " : " + (String)e.getValue());
            }

         }
      }
   }

   public synchronized Collection getAll() {
      return new ArrayList(this.map.entrySet());
   }

   public int getCacheSize() {
      return this.cacheSize;
   }

   public Entry getEldestKey() {
      return this.eldestKey;
   }

   public void setEldestKey(Entry eldestKey) {
      this.eldestKey = eldestKey;
   }
}
